@@ -26,7 +26,9 @@ from pathlib import Path
 # So we import it here first, so that the testsuite doesn't appear to fail.
 import subprocess
 
-from testutil import getStdout, Watcher, str_warn, str_info, print_table, shorten_metric_name
+from concurrent.futures import ThreadPoolExecutor
+
+from testutil import getStdout, str_warn, str_info, print_table, shorten_metric_name
 from testglobals import getConfig, ghc_env, getTestRun, TestConfig, \
                         TestOptions, brokens, PerfMetric
 from my_typing import TestName
@@ -42,6 +44,9 @@ import cpu_features
 os.environ['TERM'] = 'vt100'
 ghc_env['TERM'] = 'vt100'
 
+# Ensure that GHC doesn't go looking for environment files. See #21365.
+ghc_env['GHC_ENVIRONMENT'] = "-"
+
 global config
 config = getConfig() # get it from testglobals
 config.validate()
@@ -147,7 +152,6 @@ config.broken_tests |= {TestName(t) for t in args.broken_test}
 
 if args.threads:
     config.threads = args.threads
-    config.use_threads = True
 
 if args.verbose is not None:
     config.verbose = args.verbose
@@ -414,14 +418,22 @@ def tabulate_metrics(metrics: List[PerfMetric]) -> None:
         "{}".format(x.change.hint())
     )) for x in sorted(metrics, key =
                       lambda m: (m.stat.test, m.stat.way, m.stat.metric))]
-    geoMean = geometric_mean([
+
+    changes = [
         x.stat.value / x.baseline.perfStat.value
         for x in metrics
         if x.baseline is not None
-    ])
+    ]
+    minimum = 0.0
+    maximum = 0.0
+    if len(changes) > 0:
+      minimum = 100 * (min(changes) - 1)
+      maximum = 100 * (max(changes) - 1)
     dataRows += [
         row(("", "", "", "", "", "", "", "")),
-        row(("geo. mean", "", "", "", "", "", "{:+4.1f}%".format(100*(geoMean-1)), ""))
+        row(("geo. mean", "", "", "", "", "", "{:+4.1f}%".format(100*(geometric_mean(changes)-1)), "")),
+        row(("minimum  ", "", "", "", "", "", "{:+4.1f}%".format(minimum), "")),
+        row(("maximum  ", "", "", "", "", "", "{:+4.1f}%".format(maximum), "")),
     ]
     print_table(headerRows, dataRows, 1)
     print("")
@@ -471,26 +483,28 @@ if config.list_broken:
         print('WARNING:', len(t.framework_failures), 'framework failures!')
         print('')
 else:
-    # completion watcher
-    watcher = Watcher(len(parallelTests))
-
     # Now run all the tests
     try:
-        for oneTest in parallelTests:
-            if stopping():
-                break
-            oneTest(watcher)
+        with ThreadPoolExecutor(max_workers=config.threads) as executor:
+            for oneTest in parallelTests:
+                if stopping():
+                    break
+                oneTest(executor)
 
-        # wait for parallel tests to finish
-        if not stopping():
-            watcher.wait()
+            # wait for parallel tests to finish
+            if not stopping():
+                executor.shutdown(wait=True)
 
         # Run the following tests purely sequential
-        config.use_threads = False
-        for oneTest in aloneTests:
-            if stopping():
-                break
-            oneTest(watcher)
+        with ThreadPoolExecutor(max_workers=1) as executor:
+            for oneTest in aloneTests:
+                if stopping():
+                    break
+                oneTest(executor)
+
+            if not stopping():
+                executor.shutdown(wait=True)
+
     except KeyboardInterrupt:
         pass
 
