@@ -1,5 +1,5 @@
 {-# LANGUAGE OverloadedStrings #-}
-import Ar
+import GHC.SysTools.Ar
 
 -- obtained from echo -n \0 > x.o && ar -q b.a x.o && cat b.a
 archive = "!<arch>\nx.o/            0           0     0     644     1         \
