@@ -13,14 +13,14 @@ import GHC (GhcPs)
 testMe :: HsExpr GhcPs -> Int
 testMe (HsVar a b) = _
 testMe (HsUnboundVar xuv uv) = _
-testMe (HsOverLabel xol m_ip) = _
+testMe (HsOverLabel xol s m_ip) = _
 testMe (HsIPVar xv hin) = _
 testMe (HsOverLit xole hol) = _
 testMe (HsLit xle hl) = _
 testMe (HsLam xl mg) = _
 testMe (HsLamCase xlc lc_variant mg) = _
 testMe (HsApp xa gl gl') = _
-testMe (HsAppType xate gl hwcb) = _
+testMe (HsAppType xate gl at hwcb) = _
 testMe (OpApp xoa gl gl' gl2) = _
 testMe (NegApp xna gl se) = _
 testMe (HsPar xp gl ab ac) = _
@@ -40,7 +40,8 @@ testMe (ExprWithTySig xewts gl hwcb) = _
 testMe (ArithSeq xas m_se asi) = _
 testMe (HsTypedBracket xb hb) = _
 testMe (HsUntypedBracket xb hb) = _
-testMe (HsSpliceE xse hs) = _
+testMe (HsTypedSplice xs hs) = _
+testMe (HsUntypedSplice xs hs) = _
 testMe (HsProc xp pat gl) = _
 testMe (HsStatic xs gl) = _
 testMe (XExpr xe) = _
